'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

exports.default = initUpdateState;

var _appManagerError = require('./app-manager-error');

var _appManagerError2 = _interopRequireDefault(_appManagerError);

var _constants = require('../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function initUpdateState(apps, options) {
  return function updateState(resource, prevApp, eventTitle) {
    var errData = {
      source: 'get_state',
      fragment: null,
      slot: null
    };

    var appName = null;

    if (typeof options.getAppNameFromUrl === 'function') {
      try {
        appName = options.getAppNameFromUrl(resource);
      } catch (err) {
        throw new _appManagerError2.default(err, (0, _assign2.default)({}, errData, {
          level: _constants.levels.ERROR,
          code: 'get_app_name_from_location',
          recoverable: false
        }));
      }
    }

    if (!appName) {
      return null;
    }

    var additionalState = {};

    if (typeof options.getAdditionalState === 'function') {
      try {
        additionalState = options.getAdditionalState(appName, resource);
      } catch (err) {
        throw new _appManagerError2.default(err, (0, _assign2.default)({}, errData, {
          level: _constants.levels.ERROR,
          code: 'get_additional_state',
          recoverable: false
        }));
      }
    }

    return (0, _assign2.default)({}, additionalState, {
      event: eventTitle && typeof eventTitle === 'string' ? eventTitle : null,
      resource: resource,
      prevApp: prevApp,
      app: apps[appName]
    });
  };
}